iterm-tab-color
===============

## Usage

* Named colors: `iterm-tab-color red` (red, blue, green, ...)
* Hex codes: `iterm-tab-color "#4183C4"`
* ANSI 256 colors: `iterm-tab-color 77`

It works inside tmux too.


## Installation

```
pip install iterm-tab-color
```
